@@ -8,6 +8,7 @@ from json.decoder import JSONDecodeError
 from aomaker.log import logger
 from aomaker.cache import Config, Cache, Schema
 from aomaker.aomaker import genson
+from aomaker.exceptions import HttpRequestError
 
 
 def request(func):
@@ -45,7 +46,7 @@ def request(func):
             logger.info(f"请求成功,状态码：{str(response.status_code)}")
         else:
             logger.warning(f"请求失败,状态码：{str(response.status_code)}")
-            raise ValueError("请求失败")
+            raise HttpRequestError(str(response.status_code))
         duration = response.elapsed.total_seconds()
         logger.debug(f"请求耗时 =====> {duration}s")
 
