@@ -10,6 +10,7 @@ ALLURE_HTML_PATH = os.path.join(REPORT_DIR, "html")
 ALLURE_JSON_PATH = os.path.join(REPORT_DIR, "json")
 WIDGETS_PATH = os.path.join(ALLURE_HTML_PATH, "widgets")
 SUMMARY_JSON_PATH = os.path.join(WIDGETS_PATH, "summary.json")
+PYTEST_MARKS = ["dependency", "skip", "skipif", "xfail", "usefixtures", "filterwarnings"]
 
 
 def gen_allure_summary() -> dict:
@@ -63,14 +64,20 @@ def _handle_tags(tags: list, sep=None):
         if sep is None:
             split_tag = tag.split()
             return split_tag
-        if "dependency" in tag:
-            # 针对使用dependency插件的问题
+        if __check_pytest_marks(tag) is False:
             continue
         split_tag = tag.split(sep)
         if len(split_tag) > 0:
             return split_tag[0]
 
 
+def __check_pytest_marks(tag: str):
+    for m in PYTEST_MARKS:
+        if m in tag:
+            return False
+    return True
+
+
 def _count_passed_rate(results: dict) -> dict:
     new_results = results
     for product, result in results.items():
